@@ -1,6 +1,5 @@
 #' A not-too-fast but accurate kNN implementation supporting multiple distance measures
 #' 
-#' @docType package
 #' @rdname knn.covertree-package
 #' @name knn.covertree
 #' 
@@ -8,4 +7,4 @@
 ## Make sure Rcpp and RcppEigen are loaded
 #' @importFrom Rcpp evalCpp
 #' @importFrom RcppEigen RcppEigen.package.skeleton
-NULL
+"_PACKAGE"
